@@ -199,19 +199,20 @@ def _python_requires(
         return _format_python_requires(minimum, excluded)
 
 
-def _requires(cfg: configparser.ConfigParser, which: str) -> List[str]:
-    raw = cfg.get('options', which, fallback='')
+def _requires(
+        cfg: configparser.ConfigParser, which: str, section: str = 'options',
+) -> List[str]:
+    raw = cfg.get(section, which, fallback='')
 
-    install_requires = raw.strip().splitlines()
-    if not install_requires:
+    require_group = raw.strip().splitlines()
+    if not require_group:
         return []
 
     normalized = sorted(
-        (_normalize_req(req) for req in install_requires),
+        (_normalize_req(req) for req in require_group),
         key=lambda req: (';' in req, _req_base(req), req),
     )
     normalized.insert(0, '')
-
     return normalized
 
 
@@ -372,6 +373,11 @@ def format_file(
     if setup_requires:
         cfg['options']['setup_requires'] = '\n'.join(setup_requires)
 
+    if cfg.has_section('options.extras_require'):
+        for key in cfg['options.extras_require']:
+            group_requires = _requires(cfg, key, 'options.extras_require')
+            cfg['options.extras_require'][key] = '\n'.join(group_requires)
+
     py_classifiers = _py_classifiers(requires, max_py_version=max_py_version)
     if py_classifiers:
         cfg['metadata']['classifiers'] = (
@@ -445,6 +451,7 @@ def main(argv: Optional[Sequence[str]] = None) -> int:
     parser.add_argument('--max-py-version', type=_ver_type, default=(3, 8))
     args = parser.parse_args(argv)
 
+    retv = 0
     for filename in args.filenames:
         if format_file(
                 filename,
@@ -452,7 +459,8 @@ def main(argv: Optional[Sequence[str]] = None) -> int:
                 max_py_version=args.max_py_version,
         ):
             print(f'Rewriting {filename}')
-    return 0
+            retv = 1
+    return retv
 
 
 if __name__ == '__main__':
